@@ -58,13 +58,9 @@ if mm_cfg.GZIP_ARCHIVE_TXT_FILES:
 
 
 def html_quote(s):
-    repls = ( ('&', '&amp;'),
-	      ("<", '&lt;'),
-	      (">", '&gt;'),
-	      ('"', '&quot;'))
-    for thing, repl in repls:
-	s = string.replace(s, thing, repl)
-    return s
+    return cgi.escape(s, 1)
+
+CGIescape = html_quote
 
 def url_quote(s):
     return urllib.quote(s)
@@ -136,10 +132,6 @@ article_template='''\
 html_charset = '<META http-equiv="Content-Type" ' \
                'content="text/html; charset=%s">'
 
-def CGIescape(arg): 
-    s = cgi.escape(str(arg))
-    return string.replace(s, '"', '&quot;')
-
 # Parenthesized human name
 paren_name_pat = re.compile(r'([(].*[)])') 
 
@@ -877,8 +869,10 @@ class HyperArchive(pipermail.T):
             subject = d.get("subject", article.subject)
             author = d.get("author", article.author)
         else:
-            subject = CGIescape(article.subject)
-            author = CGIescape(article.author)
+            subject = article.subject
+            author = article.author
+        subject = CGIescape(subject)
+        author = CGIescape(author)
         print index_entry_template % (urllib.quote(article.filename),
                                       subject, article.sequence, author)
 
