@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -68,7 +68,7 @@ def main():
         mlist = MailList.MailList(listname, lock=0)
     except Errors.MMListError, e:
         # Avoid cross-site scripting attack
-        safelistname = cgi.escape(listname)
+        safelistname = Utils.QuoteHyperChars(listname)
         FormatAdminOverview('No such list <em>%s</em>' % safelistname)
         syslog('error', 'Someone tried to access the admin interface for a '
                'non-existent list: %s' % listname)
