@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -50,7 +50,7 @@ def main():
         mlist = MailList.MailList(listname, lock=0)
     except Errors.MMListError, e:
         # Avoid cross-site scripting attack
-        safelistname = cgi.escape(listname)
+        safelistname = Utils.QuoteHyperChars(listname)
         doc.AddItem(Header(2, 'No such list <em>%s</em>' % safelistname))
         print doc.Format(bgcolor='#ffffff')
         syslog('error', 'No such list "%s": %s\n' % (listname, e))
@@ -77,7 +77,7 @@ def main():
                 break
         else:
             # Avoid cross-site scripting attack
-            safetmplname = cgi.escape(template_name)
+            safetmplname = Utils.QuoteHyperChars(template_name)
             doc.SetTitle('Edit HTML : Error')
             doc.AddItem(Header(2, "%s: Invalid template" % safetmplname))
             doc.AddItem(mlist.GetMailmanFooter())
