@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000,2001 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -131,7 +131,7 @@ def main():
         mlist.IsListInitialized()
     except Errors.MMListError, e:
         # Avoid cross-site scripting attacks
-        safelistname = cgi.escape(listname)
+        safelistname = Utils.QuoteHyperChars(listname)
         msg = 'No such list <em>%s</em>' % safelistname
         doc.SetTitle("Private Archive Error - %s" % msg)
         doc.AddItem(Header(2, msg))
@@ -193,8 +193,8 @@ def main():
             f = open(true_filename, 'r')
     except IOError:
         # Avoid cross-site scripting attacks
-        safetruefilename = cgi.escape(true_filename)
-        safepath = cgi.escape(path)
+        safetruefilename = Utils.QuoteHyperChars(true_filename)
+        safepath = Utils.QuoteHyperChars(path)
         print 'Content-type: text/html\n'
 
         print "<H3>Archive File Not Found</H3>"
