@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -310,7 +310,13 @@ class Digest:
                 lines.append("Content-type: text/plain; charset=us-ascii")
                 lines.append("Content-description: Digest Footer")
             lines.append('')
-            lines.append(self.__mlist.digest_footer % self.TemplateRefs())
+            try:
+                lines.append(self.__mlist.digest_footer % self.TemplateRefs())
+            except (ValueError, TypeError), e:
+                syslog('error',
+                       'Exception while calculating digest footer: %s\n%s' %
+                       (self.__mlist.internal_name(), e))
+                lines.append('[INVALID FOOTER]')
         # Close:
         if mime:
             # Close encompassing mime envelope.
