@@ -120,8 +120,8 @@ class MailCommandHandler:
         # of these clues, so there's little we can do to break loops in that
         # case, except throttle the number of responses sent to any one
         # requester in a day.  That's a job for MM2.1.
-        precedence = msg.get('precedence', '').lower()
-        ack = msg.get('x-ack', '').lower()
+        precedence = string.lower(msg.get('precedence', ''))
+        ack = string.lower(msg.get('x-ack', ''))
         beenthere = msg.get('x-beenthere', '')
         listid = msg.get('list-id', '')
         if (precedence in ('bulk', 'list', 'junk') or
