@@ -765,6 +765,9 @@ def make_msgid(idstring=None):
     try:
         idhost = socket.getfqdn()
     except AttributeError:
-        idhost = socket.gethostbyaddr(socket.gethostname())[0]
+        try:
+            idhost = socket.gethostbyaddr(socket.gethostname())[0]
+        except socket.error:
+            idhost = mm_cfg.DEFAULT_HOST_NAME
     msgid = '<%s.%s.%s%s@%s>' % (utcdate, pid, randint, idstring, idhost)
     return msgid
